database_symbolic_data: Database from the SymbolicData project
==============================================================

Description
-----------

The SymbolicData project is set out

-  to develop concepts and tools for profiling, testing and benchmarking
   Computer Algebra Software
   (CAS) and

-  to collect and interlink relevant data and activities from different
   Computer Algebra Communities.

SymbolicData is an

-  inter-community project that has its roots in the activities of
   different Computer Algebra Communities and
-  aims at interlinking these activities using modern Semantic Web
   concepts.

Tools and data are designed to be used both

-  on a local site for special testing and profiling purposes
-  and to manage a central repository at www.symbolicdata.org.

License
-------

GNU General Public License


Upstream Contact
----------------

-  Andreas Nareike <nareike@informatik.uni-leipzig.de>

Dependencies
------------


Special Update/Build Instructions
---------------------------------

List patches that need to be applied and what they do
